==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>La comprovació ja s&apos;acaba. Gràcies per la paciència!</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Es prepara</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>S&apos;ha comprovat si hi ha errors.</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ves a l&apos;escriptori</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Us donem la benvinguda. El sistema s&apos;ha actualitzat correctament.</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Edició actual:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Mostra els registres</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Actualitzacions correctes</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>L&apos;ordinador es reiniciarà aviat: %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>L&apos;ordinador s&apos;aturarà aviat: %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>El procés de reinici automàtic ha fallat. Si us plau, proveu de reiniciar el dispositiu manualment.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>El procés d&apos;aturada automàtica ha fallat. Si us plau, proveu d&apos;aturar el dispositiu manualment.</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Amaga els registres</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Ha fallat l&apos;actualització.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconegut</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Ha fallat la còpia de seguretat.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>No es pot fer una còpia de seguretat del sistema. Si continueu les actualitzacions, no podreu tornar al sistema anterior més tard.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Espai en disc insuficient. Buideu el disc i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Ha fallat connectar amb els serveis de còpia de seguretat. Comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Ha fallat connectar amb els serveis d&apos;actualització. Comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Error de dependència</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Error de DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Torna a fer una còpia de seguretat</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Avorta-ho</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Procedeix a l&apos;actualització</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia&apos;t</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ves a l&apos;escriptori</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Es preparen les actualitzacions...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>No forceu l&apos;aturada quan s&apos;instal·len actualitzacions. El sistema es podria danyar.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.35.tar.xz: BUILD/src/dde-update/translations/dde-update_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>La comprovació ja s&apos;acaba. Gràcies per la paciència!</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Es prepara</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>S&apos;ha comprovat si hi ha errors.</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ves a l&apos;escriptori</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Us donem la benvinguda. El sistema s&apos;ha actualitzat correctament.</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Edició actual:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Actualitzacions correctes</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>L&apos;ordinador es reiniciarà aviat: %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>L&apos;ordinador s&apos;aturarà aviat: %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>El procés de reinici automàtic ha fallat. Si us plau, proveu de reiniciar el dispositiu manualment.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>El procés d&apos;aturada automàtica ha fallat. Si us plau, proveu d&apos;aturar el dispositiu manualment.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Mostra els registres d&apos;actualització</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Replega els registres d&apos;actualització</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>El registre s&apos;ha exportat a l&apos;escriptori.</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>L&apos;exportació del registre ha fallat. Torneu-ho a provar.</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Ha fallat l&apos;actualització.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconegut</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Ha fallat la còpia de seguretat.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>No es pot fer una còpia de seguretat del sistema. Si continueu les actualitzacions, no podreu tornar al sistema anterior més tard.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Espai en disc insuficient. Buideu el disc i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Ha fallat connectar amb els serveis de còpia de seguretat. Comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Ha fallat connectar amb els serveis d&apos;actualització. Comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Error de dependència</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Error de DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Torna a fer una còpia de seguretat</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Avorta-ho</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Procedeix a l&apos;actualització</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia&apos;t</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ves a l&apos;escriptori</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Es preparen les actualitzacions...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>No forceu l&apos;aturada quan s&apos;instal·len actualitzacions. El sistema es podria danyar.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Mostra els registres d&apos;actualització</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Replega els registres d&apos;actualització</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>registre d&apos;actualització</translation>
    </message>
</context>
</TS>
